@@ -16,13 +16,8 @@
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    // enable high dpi support
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-#endif
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("kmousetool");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kmousetool"));
 
     KAboutData aboutData(QStringLiteral("kmousetool"),
                          i18n("KMouseTool"),
@@ -52,7 +47,7 @@ int main(int argc, char *argv[])
 
     KMouseTool *kmousetool = new KMouseTool();
 
-    if (!KSharedConfig::openConfig()->group("UserOptions").readEntry("IsMinimized", false))
+    if (!KSharedConfig::openConfig()->group(QStringLiteral("UserOptions")).readEntry("IsMinimized", false))
         kmousetool->show();
 
     return app.exec();
